@@ -1003,23 +1003,6 @@ TRANS(SocketUNIXCreateListener) (XtransConnInfo ciptr, const char *port,
     if (abstract) {
 	sockname.sun_path[0] = '\0';
 	namelen = offsetof(struct sockaddr_un, sun_path) + 1 + strlen(&sockname.sun_path[1]);
-    } else {
-	char lock[108+5];
-	int lock_fd;
-
-	snprintf(lock, sizeof(lock), "%s.lock", sockname.sun_path);
-	lock_fd = open(lock, O_RDONLY | O_CREAT, 0600);
-	if (lock_fd < 0)
-	  return TRANS_CREATE_LISTENER_FAILED;
-
-	if (flock(lock_fd, LOCK_EX | LOCK_NB) < 0) {
-	  close(lock_fd);
-	  return TRANS_ADDR_IN_USE;
-	}
-
-	/* If another server process doesn't already have this socket bound,
-	   it's ok to unlink and bind */
-	unlink (sockname.sun_path);
     }
 
     if ((status = TRANS(SocketCreateListener) (ciptr,
